@@ -31,7 +31,7 @@ makeVerticalFacePredicate(double sliceCoord)
   using Element = typename GridView::Traits::template Codim<0>::Entity;
   auto predicate = [sliceCoord](const Element& element, unsigned int face) -> bool {
     const int dim = GridView::dimension;
-    const Dune::ReferenceElement<double,dim>& refElement = Dune::ReferenceElements<double, dim>::general(element.type());
+    const auto& refElement = Dune::ReferenceElements<double, dim>::general(element.type());
 
     int numVertices = refElement.size(face, 1, dim);
 
@@ -72,7 +72,7 @@ void testMatchingCubeGrids()
   using GridType = Dune::YaspGrid<dim, Dune::EquidistantOffsetCoordinates<double, dim> >;
 
   std::array<int, dim> elements;
-  elements.fill(1);
+  elements.fill(8);
   FieldVector<double,dim> lower(0);
   FieldVector<double,dim> upper(1);
 
@@ -133,13 +133,13 @@ void testNonMatchingCubeGrids()
   using GridType = Dune::YaspGrid<dim, Dune::EquidistantOffsetCoordinates<double, dim> >;
 
   std::array<int, dim> elements;
-  elements.fill(2);
+  elements.fill(8);
   FieldVector<double,dim> lower(0);
   FieldVector<double,dim> upper(1);
 
   GridType cubeGrid0(lower, upper, elements);
 
-  elements.fill(4);
+  elements.fill(10);
   lower[0] += 1;
   upper[0] += 1;
 
@@ -196,13 +196,13 @@ public:
   std::shared_ptr<GridType> generate()
   {
     std::array<int, dim> elements;
-    elements.fill(2);
+    elements.fill(8);
     FieldVector<double,dim> lower(0);
     FieldVector<double,dim> upper(1);
 
     if (tar)
     {
-      elements.fill(4);
+      elements.fill(10);
       lower[0] += 1;
       upper[0] += 1;
     }
@@ -225,7 +225,7 @@ public:
   std::shared_ptr<GridType> generate()
   {
     std::array<int,dim> elements;
-    std::fill(elements.begin(), elements.end(), 2);
+    std::fill(elements.begin(), elements.end(), 8);
     std::bitset<dim> periodic(0);
     FieldVector<double,dim> size(1);
     int overlap = 1;
@@ -233,7 +233,7 @@ public:
 
     if (tar)
     {
-      std::fill(elements.begin(), elements.end(), 4);
+      std::fill(elements.begin(), elements.end(), 10);
       shift = 1.0;
     }
 
@@ -320,7 +320,7 @@ void eh( MPI_Comm *comm, int *err, ... )
 }
 #endif // HAVE_MPI
 
-int main(int argc, char *argv[]) try
+int main(int argc, char *argv[])
 {
   Dune::MPIHelper::instance(argc, argv);
   Dune::dinfo.attach(std::cout);
@@ -373,8 +373,3 @@ int main(int argc, char *argv[]) try
 
   return 0;
 }
-catch (Exception e) {
-  int i = 0; char** c = 0;
-  std::cout << Dune::MPIHelper::instance(i,c).rank() << ": " << e << std::endl;
-  return 1;
-}
