@@ -2,6 +2,7 @@
 // vi: set et ts=4 sw=2 sts=2:
 #include <config.h>
 
+#include <array>
 #include <memory>
 
 #include <dune/grid/yaspgrid.hh>
@@ -162,7 +163,7 @@ void testSimplexGridsUG(std::shared_ptr< Merger<double,dim,dim,dim> > merger, co
 
   FieldVector<double,dim> lowerLeft(0);
   FieldVector<double,dim> upperRight(1);
-  array<unsigned int, dim> elements;
+  std::array<unsigned int, dim> elements;
   std::fill(elements.begin(), elements.end(), 10);
 
   StructuredGridFactory<GridType> factory;
@@ -252,7 +253,7 @@ void testHybridGridsUG(std::shared_ptr< Merger<double,dim,dim,dim> > merger, con
 #endif
 
 
-int main(int argc, char** argv) try
+int main(int argc, char** argv)
 {
   Dune::MPIHelper::instance(argc, argv);
 
@@ -266,10 +267,10 @@ int main(int argc, char** argv) try
   testCubeGrids<2>(overlappingMerge2d, FieldVector<double,2>(0.05));
 
   testSimplexGrids<1>(overlappingMerge1d, FieldVector<double,1>(0.05));
-#if HAVE_UG && !HAVE_UG_PARALLEL
+#if HAVE_UG
   testSimplexGridsUG<2>(overlappingMerge2d, FieldVector<double,2>(0.05));
 #endif
-#if HAVE_UG && !HAVE_UG_PARALLEL && HAVE_HYBRIDTESTGRIDS
+#if HAVE_UG && HAVE_HYBRIDTESTGRIDS
   testHybridGridsUG<2>(overlappingMerge2d, FieldVector<double,2>(0.05));
 #endif
 
@@ -285,13 +286,10 @@ int main(int argc, char** argv) try
   testCubeGrids<2>(conformingMerge2d, FieldVector<double,2>(0));
 
   testSimplexGrids<1>(conformingMerge1d, FieldVector<double,1>(0));
-#if HAVE_UG && !HAVE_UG_PARALLEL
+#if HAVE_UG
   testSimplexGridsUG<2>(conformingMerge2d, FieldVector<double,2>(0));
 #endif
-#if HAVE_UG && !HAVE_UG_PARALLEL && HAVE_HYBRIDTESTGRIDS
+#if HAVE_UG && HAVE_HYBRIDTESTGRIDS
   testHybridGridsUG<2>(conformingMerge2d, FieldVector<double,2>(0));
 #endif
-} catch (Exception e) {
-  std::cout << e << std::endl;
-  return 1;
 }
